pub struct Writer { /* private fields */ }Expand description
Writer for loam files
The writer can be used to create or append to an existing file.
Implementations
Sourceimpl Writer
impl Writer
Sourcepub fn checkpoint(&mut self, id: Id) -> Result<()>
pub fn checkpoint(&mut self, id: Id) -> Result<()>
Add a checkpoint to the file. The Id commonly points to the root of a
tree of nodes.
In order to be read back, a file must end with a checkpoint.